Crate pictorat

Crate pictorat 

A ratatui widget that renders an image.

Structs

Braille
Render images using Unicode braille characters.
TerminalImage
A widget that can draw an image onto the terminal.

Traits

ImageMethod
The interface for how an image is to be drawn to the terminal.