A ratatui widget that renders an image.
Structs
- Braille
- Render images using Unicode braille characters.
- Terminal
Image - A widget that can draw an image onto the terminal.
Traits
- Image
Method - The interface for how an image is to be drawn to the terminal.